@@ -174,18 +174,19 @@ template
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE F memmove(I f, I l, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {
-   typedef typename boost::container::iterator_traits<I>::value_type value_type;
+   typedef typename boost::container::iterator_traits<I>::value_type      value_type;
+   typedef typename boost::container::iterator_traits<F>::difference_type r_difference_type;
    value_type *const dest_raw = boost::movelib::iterator_to_raw_pointer(r);
    const value_type *const beg_raw = boost::movelib::iterator_to_raw_pointer(f);
    const value_type *const end_raw = boost::movelib::iterator_to_raw_pointer(l);
    if(BOOST_LIKELY(beg_raw != end_raw && dest_raw && beg_raw)){
-      const typename boost::container::iterator_traits<I>::difference_type n = end_raw - beg_raw;
+      const std::size_t n = std::size_t(end_raw - beg_raw)   ;
       // 2019-02-06, Jisu KIM
       // Temporarily fixing [-Wclass-memaccess] warning in debian
       //std::memmove(dest_raw, beg_raw, sizeof(value_type)*n);
       std::memmove(static_cast<void *>(dest_raw), beg_raw,
-          sizeof(value_type)*n);      
-      r += n;
+          sizeof(value_type)*n);
+      r += static_cast<r_difference_type>(n);
    }
    return r;
 }
@@ -197,14 +198,15 @@ template
 BOOST_CONTAINER_FORCEINLINE F memmove_n(I f, U n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {
    typedef typename boost::container::iterator_traits<I>::value_type value_type;
-   if(BOOST_LIKELY(n)){
+   typedef typename boost::container::iterator_traits<F>::difference_type r_difference_type;
+   if(BOOST_LIKELY(n != 0)){
       // 2019-02-06, Jisu KIM
       // Temporarily fixing [-Wclass-memaccess] warning in debian
       //std::memmove(boost::movelib::iterator_to_raw_pointer(r), boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);
       std::memmove(
           static_cast<void *>(boost::movelib::iterator_to_raw_pointer(r)),
-          boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);      
-      r += n;
+          boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);
+      r += static_cast<r_difference_type>(n);
    }
 
    return r;
@@ -212,34 +214,36 @@ BOOST_CONTAINER_FORCEINLINE F memmove_n(I f, U n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 
 template
    <typename I, // I models InputIterator
-    typename U, // U models unsigned integral constant
     typename F> // F models ForwardIterator
-BOOST_CONTAINER_FORCEINLINE I memmove_n_source(I f, U n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+BOOST_CONTAINER_FORCEINLINE I memmove_n_source(I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {
-   if(BOOST_LIKELY(n)){
+   if(BOOST_LIKELY(n != 0)){
       typedef typename boost::container::iterator_traits<I>::value_type value_type;
+      typedef typename boost::container::iterator_traits<I>::difference_type i_difference_type;
       // 2019-02-06, Jisu KIM
       // Temporarily fixing [-Wclass-memaccess] warning in debian
       //std::memmove(boost::movelib::iterator_to_raw_pointer(r), boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);
       std::memmove(
           static_cast<void *>(boost::movelib::iterator_to_raw_pointer(r)),
           boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);
-      f += n;
+      f += static_cast<i_difference_type>(n);
    }
    return f;
 }
 
 template
    <typename I, // I models InputIterator
-    typename U, // U models unsigned integral constant
     typename F> // F models ForwardIterator
-BOOST_CONTAINER_FORCEINLINE I memmove_n_source_dest(I f, U n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
+BOOST_CONTAINER_FORCEINLINE I memmove_n_source_dest(I f, std::size_t n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
 {
    typedef typename boost::container::iterator_traits<I>::value_type value_type;
-   if(BOOST_LIKELY(n)){
+   typedef typename boost::container::iterator_traits<F>::difference_type i_difference_type;
+   typedef typename boost::container::iterator_traits<F>::difference_type f_difference_type;
+
+   if(BOOST_LIKELY(n != 0)){
       std::memmove(boost::movelib::iterator_to_raw_pointer(r), boost::movelib::iterator_to_raw_pointer(f), sizeof(value_type)*n);
-      f += n;
-      r += n;
+      f += i_difference_type(n);
+      r += f_difference_type(n);
    }
    return f;
 }
@@ -352,7 +356,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 inline typename dtl::disable_if_memtransfer_copy_constructible<I, F, F>::type
-   uninitialized_move_alloc_n(Allocator &a, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_move_alloc_n(Allocator &a, I f, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -377,7 +381,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_constructible<I, F, F>::type
-   uninitialized_move_alloc_n(Allocator &, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   uninitialized_move_alloc_n(Allocator &, I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -398,7 +402,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 inline typename dtl::disable_if_memtransfer_copy_constructible<I, F, I>::type
-   uninitialized_move_alloc_n_source(Allocator &a, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_move_alloc_n_source(Allocator &a, I f, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -423,7 +427,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_constructible<I, F, I>::type
-   uninitialized_move_alloc_n_source(Allocator &, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   uninitialized_move_alloc_n_source(Allocator &, I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -489,7 +493,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 inline typename dtl::disable_if_memtransfer_copy_constructible<I, F, F>::type
-   uninitialized_copy_alloc_n(Allocator &a, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_copy_alloc_n(Allocator &a, I f, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -514,7 +518,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_constructible<I, F, F>::type
-   uninitialized_copy_alloc_n(Allocator &, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   uninitialized_copy_alloc_n(Allocator &, I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -535,7 +539,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 inline typename dtl::disable_if_memtransfer_copy_constructible<I, F, I>::type
-   uninitialized_copy_alloc_n_source(Allocator &a, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_copy_alloc_n_source(Allocator &a, I f, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -559,7 +563,7 @@ template
     typename I, // I models InputIterator
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_constructible<I, F, I>::type
-   uninitialized_copy_alloc_n_source(Allocator &, I f, typename boost::container::allocator_traits<Allocator>::size_type n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   uninitialized_copy_alloc_n_source(Allocator &, I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -579,7 +583,7 @@ template
    <typename Allocator,
     typename F> // F models ForwardIterator
 inline typename dtl::disable_if_memzero_initializable<F, F>::type
-   uninitialized_value_init_alloc_n(Allocator &a, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_value_init_alloc_n(Allocator &a, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -603,12 +607,14 @@ template
    <typename Allocator,
     typename F> // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memzero_initializable<F, F>::type
-   uninitialized_value_init_alloc_n(Allocator &, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+   uninitialized_value_init_alloc_n(Allocator &, std::size_t n, F r)
 {
    typedef typename boost::container::iterator_traits<F>::value_type value_type;
-   if (BOOST_LIKELY(n)){
+   typedef typename boost::container::iterator_traits<F>::difference_type r_difference_type;
+
+   if (BOOST_LIKELY(n != 0)){
       std::memset((void*)boost::movelib::iterator_to_raw_pointer(r), 0, sizeof(value_type)*n);
-      r += n;
+      r += static_cast<r_difference_type>(n);
    }
    return r;
 }
@@ -629,7 +635,7 @@ BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memzero_initializable<F, F>:
 template
    <typename Allocator,
     typename F> // F models ForwardIterator
-inline F uninitialized_default_init_alloc_n(Allocator &a, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+inline F uninitialized_default_init_alloc_n(Allocator &a, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -702,7 +708,7 @@ template
    <typename Allocator,
     typename T,
     typename F> // F models ForwardIterator
-inline F uninitialized_fill_alloc_n(Allocator &a, const T &v, typename boost::container::allocator_traits<Allocator>::size_type n, F r)
+inline F uninitialized_fill_alloc_n(Allocator &a, const T &v, std::size_t n, F r)
 {
    F back = r;
    BOOST_TRY{
@@ -800,10 +806,9 @@ inline typename dtl::disable_if_memtransfer_copy_assignable<I, F, I>::type
 
 template
 <typename I,   // I models InputIterator
-typename U,   // U models unsigned integral constant
 typename F>   // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<I, F, I>::type
-   copy_n_source(I f, U n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   copy_n_source(I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -814,10 +819,9 @@ BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<
 
 template
 <typename I,   // I models InputIterator
-typename U,   // U models unsigned integral constant
 typename F>   // F models ForwardIterator
 inline typename dtl::disable_if_memtransfer_copy_assignable<I, F, I>::type
-   copy_n_source_dest(I f, U n, F &r)
+   copy_n_source_dest(I f, std::size_t n, F &r)
 {
    while (n) {
       --n;
@@ -829,10 +833,9 @@ inline typename dtl::disable_if_memtransfer_copy_assignable<I, F, I>::type
 
 template
 <typename I,   // I models InputIterator
-typename U,   // U models unsigned integral constant
 typename F>   // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<I, F, I>::type
-   copy_n_source_dest(I f, U n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
+   copy_n_source_dest(I f, std::size_t n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source_dest(f, n, r);  }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -917,8 +920,8 @@ BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<
    move_backward(I f, I l, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {
    typedef typename boost::container::iterator_traits<I>::value_type value_type;
-   const typename boost::container::iterator_traits<I>::difference_type n = boost::container::iterator_distance(f, l);
-   if (BOOST_LIKELY(n)){
+   const std::size_t n = boost::container::iterator_udistance(f, l);
+   if (BOOST_LIKELY(n != 0)){
       r -= n;
       // 2019-02-06, Jisu KIM
       // Temporarily fixing [-Wclass-memaccess] warning in debian
@@ -926,7 +929,6 @@ BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<
       std::memmove(
           static_cast<void *>((boost::movelib::iterator_to_raw_pointer)(r)),
           (boost::movelib::iterator_to_raw_pointer)(f), sizeof(value_type)*n);
-
    }
    return r;
 }
@@ -954,10 +956,9 @@ inline typename dtl::disable_if_memtransfer_copy_assignable<I, F, I>::type
 
 template
 <typename I    // I models InputIterator
-,typename U    // U models unsigned integral constant
 ,typename F>   // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<I, F, I>::type
-   move_n_source_dest(I f, U n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
+   move_n_source_dest(I f, std::size_t n, F &r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source_dest(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -983,10 +984,9 @@ inline typename dtl::disable_if_memtransfer_copy_assignable<I, F, I>::type
 
 template
 <typename I    // I models InputIterator
-,typename U    // U models unsigned integral constant
 ,typename F>   // F models ForwardIterator
 BOOST_CONTAINER_FORCEINLINE typename dtl::enable_if_memtransfer_copy_assignable<I, F, I>::type
-   move_n_source(I f, U n, F r) BOOST_NOEXCEPT_OR_NOTHROW
+   move_n_source(I f, std::size_t n, F r) BOOST_NOEXCEPT_OR_NOTHROW
 {  return dtl::memmove_n_source(f, n, r); }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1030,15 +1030,14 @@ template
    ,typename G // G models ForwardIterator
    >
 inline typename dtl::disable_if_memtransfer_copy_assignable<F, G, void>::type
-   deep_swap_alloc_n( Allocator &a, F short_range_f, typename allocator_traits<Allocator>::size_type n_i
-                    , G large_range_f, typename allocator_traits<Allocator>::size_type n_j)
+   deep_swap_alloc_n( Allocator &a, F short_range_f, std::size_t  n_i, G large_range_f, std::size_t n_j)
 {
-   typename allocator_traits<Allocator>::size_type n = 0;
+   std::size_t n = 0;
    for (; n != n_i ; ++short_range_f, ++large_range_f, ++n){
       boost::adl_move_swap(*short_range_f, *large_range_f);
    }
-   boost::container::uninitialized_move_alloc_n(a, large_range_f, n_j - n_i, short_range_f);  // may throw
-   boost::container::destroy_alloc_n(a, large_range_f, n_j - n_i);
+   boost::container::uninitialized_move_alloc_n(a, large_range_f, std::size_t(n_j - n_i), short_range_f);  // may throw
+   boost::container::destroy_alloc_n(a, large_range_f, std::size_t(n_j - n_i));
 }
 
 static const std::size_t DeepSwapAllocNMaxStorage = std::size_t(1) << std::size_t(11); //2K bytes
@@ -1052,8 +1051,7 @@ template
 inline typename dtl::enable_if_c
    < dtl::is_memtransfer_copy_assignable<F, G>::value && (MaxTmpBytes <= DeepSwapAllocNMaxStorage) && false
    , void>::type
-   deep_swap_alloc_n( Allocator &a, F short_range_f, typename allocator_traits<Allocator>::size_type n_i
-                    , G large_range_f, typename allocator_traits<Allocator>::size_type n_j)
+   deep_swap_alloc_n( Allocator &a, F short_range_f, std::size_t n_i, G large_range_f, std::size_t n_j)
 {
    typedef typename allocator_traits<Allocator>::value_type value_type;
    typedef typename dtl::aligned_storage
@@ -1067,10 +1065,10 @@ inline typename dtl::enable_if_c
    std::memcpy(stora_ptr, large_ptr, n_i_bytes);
    std::memcpy(large_ptr, short_ptr, n_i_bytes);
    std::memcpy(short_ptr, stora_ptr, n_i_bytes);
-   boost::container::iterator_advance(large_range_f, n_i);
-   boost::container::iterator_advance(short_range_f, n_i);
-   boost::container::uninitialized_move_alloc_n(a, large_range_f, n_j - n_i, short_range_f);  // may throw
-   boost::container::destroy_alloc_n(a, large_range_f, n_j - n_i);
+   boost::container::iterator_uadvance(large_range_f, n_i);
+   boost::container::iterator_uadvance(short_range_f, n_i);
+   boost::container::uninitialized_move_alloc_n(a, large_range_f, std::size_t(n_j - n_i), short_range_f);  // may throw
+   boost::container::destroy_alloc_n(a, large_range_f, std::size_t(n_j - n_i));
 }
 
 template
@@ -1082,8 +1080,7 @@ template
 inline typename dtl::enable_if_c
    < dtl::is_memtransfer_copy_assignable<F, G>::value && true//(MaxTmpBytes > DeepSwapAllocNMaxStorage)
    , void>::type
-   deep_swap_alloc_n( Allocator &a, F short_range_f, typename allocator_traits<Allocator>::size_type n_i
-                    , G large_range_f, typename allocator_traits<Allocator>::size_type n_j)
+   deep_swap_alloc_n( Allocator &a, F short_range_f, std::size_t n_i, G large_range_f, std::size_t n_j)
 {
    typedef typename allocator_traits<Allocator>::value_type value_type;
    typedef typename dtl::aligned_storage
@@ -1138,10 +1135,10 @@ inline typename dtl::enable_if_c
    std::memcpy(stora_ptr, large_ptr, szt_rem);
    std::memcpy(large_ptr, short_ptr, szt_rem);
    std::memcpy(short_ptr, stora_ptr, szt_rem);
-   boost::container::iterator_advance(large_range_f, n_i);
-   boost::container::iterator_advance(short_range_f, n_i);
-   boost::container::uninitialized_move_alloc_n(a, large_range_f, n_j - n_i, short_range_f);  // may throw
-   boost::container::destroy_alloc_n(a, large_range_f, n_j - n_i);
+   boost::container::iterator_uadvance(large_range_f, n_i);
+   boost::container::iterator_uadvance(short_range_f, n_i);
+   boost::container::uninitialized_move_alloc_n(a, large_range_f, std::size_t(n_j - n_i), short_range_f);  // may throw
+   boost::container::destroy_alloc_n(a, large_range_f, std::size_t(n_j - n_i));
 }
 
 
@@ -1156,16 +1153,15 @@ template
    ,typename I // F models InputIterator
    ,typename O // G models OutputIterator
    >
-void copy_assign_range_alloc_n( Allocator &a, I inp_start, typename allocator_traits<Allocator>::size_type n_i
-                              , O out_start, typename allocator_traits<Allocator>::size_type n_o )
+void copy_assign_range_alloc_n( Allocator &a, I inp_start, std::size_t n_i, O out_start, std::size_t n_o )
 {
    if (n_o < n_i){
       inp_start = boost::container::copy_n_source_dest(inp_start, n_o, out_start);     // may throw
-      boost::container::uninitialized_copy_alloc_n(a, inp_start, n_i - n_o, out_start);// may throw
+      boost::container::uninitialized_copy_alloc_n(a, inp_start, std::size_t(n_i - n_o), out_start);// may throw
    }
    else{
       out_start = boost::container::copy_n(inp_start, n_i, out_start);  // may throw
-      boost::container::destroy_alloc_n(a, out_start, n_o - n_i);
+      boost::container::destroy_alloc_n(a, out_start, std::size_t(n_o - n_i));
    }
 }
 
@@ -1180,16 +1176,15 @@ template
    ,typename I // F models InputIterator
    ,typename O // G models OutputIterator
    >
-void move_assign_range_alloc_n( Allocator &a, I inp_start, typename allocator_traits<Allocator>::size_type n_i
-                              , O out_start, typename allocator_traits<Allocator>::size_type n_o )
+void move_assign_range_alloc_n( Allocator &a, I inp_start, std::size_t n_i, O out_start, std::size_t n_o )
 {
    if (n_o < n_i){
       inp_start = boost::container::move_n_source_dest(inp_start, n_o, out_start);  // may throw
-      boost::container::uninitialized_move_alloc_n(a, inp_start, n_i - n_o, out_start);  // may throw
+      boost::container::uninitialized_move_alloc_n(a, inp_start, std::size_t(n_i - n_o), out_start);  // may throw
    }
    else{
       out_start = boost::container::move_n(inp_start, n_i, out_start);  // may throw
-      boost::container::destroy_alloc_n(a, out_start, n_o - n_i);
+      boost::container::destroy_alloc_n(a, out_start, std::size_t(n_o - n_i));
    }
 }
 
@@ -1216,7 +1211,7 @@ void uninitialized_move_and_insert_alloc
    , F pos
    , F last
    , O d_first
-   , typename allocator_traits<Allocator>::size_type n
+   , std::size_t n
    , InsertionProxy insert_range_proxy)
 {
    typedef typename array_destructor<Allocator, F>::type array_destructor_t;
@@ -1248,7 +1243,7 @@ void expand_forward_and_insert_alloc
    ( Allocator &a
    , F pos
    , F last
-   , typename allocator_traits<Allocator>::size_type n
+   , std::size_t n
    , InsertionProxy insert_range_proxy)
 {
    typedef typename array_destructor<Allocator, F>::type array_destructor_t;
@@ -1260,8 +1255,7 @@ void expand_forward_and_insert_alloc
       insert_range_proxy.uninitialized_copy_n_and_update(a, last, n);
    }
    else{
-      typedef typename allocator_traits<Allocator>::size_type alloc_size_type;
-      const alloc_size_type elems_after = static_cast<alloc_size_type>(last - pos);
+      const std::size_t elems_after = static_cast<std::size_t>(last - pos);
       if(elems_after >= n){
          //New elements can be just copied.
          //Move to uninitialized memory last objects
@@ -1281,7 +1275,7 @@ void expand_forward_and_insert_alloc
          //Copy first new elements in pos (gap is still there)
          insert_range_proxy.copy_n_and_update(a, pos, elems_after);
          //Copy to the beginning of the unallocated zone the last new elements (the gap is closed).
-         insert_range_proxy.uninitialized_copy_n_and_update(a, last, n - elems_after);
+         insert_range_proxy.uninitialized_copy_n_and_update(a, last, std::size_t(n - elems_after));
          on_exception.release();
       }
    }
